set more off
clear
set seed 1234
cd "~/Dropbox/contest/QE submission supporting document"

//treatments:
//T1 -> Baseline
//T2 -> PastInfo
//T3 -> FutureInfo
//T4 -> PastWinUn

//======================================table 14 raw performance data======================================
use raw_performance_pairing.dta,clear 

//change treatment number to run for baseline(treat==1) or PastWinUn (treat==4).
global treat = 1
//global treat = 4


keep if treatment == $treat &  round_number == 2
su p_score

cap postclose myhandle2
postfile myhandle2 MSE b  using "cross_val.dta", replace	

//change outcome variable to get outcome for effort_change, stop time change, productivity change and wining probablity change
global outcome "effort_change"
//global outcome "stop_time_change"
//global outcome "productivity_change"
//global outcome "p_win_change"


psmatch2 treated if round_number == 2 , llr outcome($outcome) bwidth(`b')  pscore(p_score)  ate   common 
keep if _support == 1
su p_score 
global b_max = round((`r(max)'-`r(min)')/2,0.01)
forvalues b =  0.01(0.001) $b_max {
	//qui: 	psmatch2 treated if round_number == 2 , llr outcome($outcome) bwidth(`b')  pscore(p_score)  ate   common 
	cap drop dif 
	
	gen dif = 0
	cap drop dif2
	gen dif2 = 0
	qui levelsof(uniq_id) , local(ids)
	foreach i of local ids {
		qui su p_score if uniq_id == `i'
		cap drop est 
		cap drop x 
		lpoly $outcome p_score if round_number == 2 & uniq_id != `i', gen(est) bw(`b') at(p_score)  nograph deg(1)
		qui replace dif = ($outcome-est) if uniq_id == `i'   
		qui replace dif2 = dif*dif if uniq_id == `i'  
		}	
	cap drop MSE
	qui egen MSE = mean(dif2)
	su MSE 
	global MSE = `r(mean)'
	post myhandle2  ($MSE) (`b') 
	}
	
		
postclose myhandle2

use "cross_val.dta",replace
su MSE
su b if MSE == r(min)
global min_bw=r(mean)
dis $min_bw

use raw_performance_pairing.dta.dta,clear //UTS dataset
keep if treatment == $treat &  round_number == 2
bootstrap r(ate), seed(1234)  rep(2000): psmatch2 treated if round_number == 2 , ///
llr outcome($outcome) bwidth($min_bw)  pscore(p_score)  ate   common 



//run this to get outcome for PastInfo treatment (treat==2)
use all_observations.dta,clear
global treat = 2
keep if treatment == $treat &  round_number == 2&new_data==0
drop if pair == 15
su p_score

cap postclose myhandle2
postfile myhandle2 MSE b  using "cross_val.dta", replace	

//change outcome variable to get outcome for effort_change, stop time change, productivity change and wining probablity change
global outcome "effort_change"
//global outcome "stop_time_change"
//global outcome "productivity_change"
//global outcome "p_win_change"

psmatch2 treated if round_number == 2 , llr outcome($outcome) bwidth(`b')  pscore(p_score)  ate   common 
keep if _support == 1
su p_score 
global b_max = round((`r(max)'-`r(min)')/2,0.01)
forvalues b =  0.01(0.001) $b_max {
	//qui: 	psmatch2 treated if round_number == 2 , llr outcome($outcome) bwidth(`b')  pscore(p_score)  ate   common 
	cap drop dif 
	
	gen dif = 0
	cap drop dif2
	gen dif2 = 0
	qui levelsof(uniq_id) , local(ids)
	foreach i of local ids {
		qui su p_score if uniq_id == `i'
		cap drop est 
		cap drop x 
		lpoly $outcome p_score if round_number == 2 & uniq_id != `i', gen(est) bw(`b') at(p_score)  nograph deg(1)
		qui replace dif = ($outcome-est) if uniq_id == `i'   
		qui replace dif2 = dif*dif if uniq_id == `i'  
		}	
	cap drop MSE
	qui egen MSE = mean(dif2)
	su MSE 
	global MSE = `r(mean)'
	post myhandle2  ($MSE) (`b') 
	}
	
		
postclose myhandle2

use "cross_val.dta",replace
su MSE
su b if MSE == r(min)
global min_bw=r(mean)
dis $min_bw

use all_data_merged.dta,clear
keep if treatment == $treat &  round_number == 2&new_data==0
drop if pair == 15
bootstrap r(ate), seed(1234) rep(2000): psmatch2 treated if round_number == 2 , ///
llr outcome($outcome) bwidth($min_bw)  pscore(p_score)  ate   common 

//=======================================================================================


//======================================table 15 contest peformance data======================================
use contest_performance_pairing.dta,clear 

//change treatment number to run for baseline(treat==1) or PastInfo (treat==2) or PastWinUn (treat==4).
global treat = 1
//global treat =2
//global treat = 4


keep if treatment == $treat &  round_number == 2
su p_score

cap postclose myhandle2
postfile myhandle2 MSE b  using "cross_val.dta", replace	

//change outcome variable to get outcome for effort_change, stop time change, productivity change and wining probablity change
global outcome "effort_change"
//global outcome "stop_time_change"
//global outcome "productivity_change"
//global outcome "p_win_change"


psmatch2 treated if round_number == 2 , llr outcome($outcome) bwidth(`b')  pscore(p_score)  ate   common 
keep if _support == 1
su p_score 
global b_max = round((`r(max)'-`r(min)')/2,0.01)
forvalues b =  0.01(0.001) $b_max {
	//qui: 	psmatch2 treated if round_number == 2 , llr outcome($outcome) bwidth(`b')  pscore(p_score)  ate   common 
	cap drop dif 
	
	gen dif = 0
	cap drop dif2
	gen dif2 = 0
	qui levelsof(uniq_id) , local(ids)
	foreach i of local ids {
		qui su p_score if uniq_id == `i'
		cap drop est 
		cap drop x 
		lpoly $outcome p_score if round_number == 2 & uniq_id != `i', gen(est) bw(`b') at(p_score)  nograph deg(1)
		qui replace dif = ($outcome-est) if uniq_id == `i'   
		qui replace dif2 = dif*dif if uniq_id == `i'  
		}	
	cap drop MSE
	qui egen MSE = mean(dif2)
	su MSE 
	global MSE = `r(mean)'
	post myhandle2  ($MSE) (`b') 
	}
	
		
postclose myhandle2

use "cross_val.dta",replace
su MSE
su b if MSE == r(min)
global min_bw=r(mean)
dis $min_bw

use contest_performance_pairing.dta,clear //UTS dataset
keep if treatment == $treat &  round_number == 2
bootstrap r(ate), seed(1234)  rep(2000): psmatch2 treated if round_number == 2 , ///
llr outcome($outcome) bwidth($min_bw)  pscore(p_score)  ate   common 


/// 

//=======================================================================================
