cd "~/Dropbox/contest/QE submission supporting document"


set more off
set seed 1234	

global rep = 2000
global bw = 0.025

/*
To generate table 3 and table 5, use "bsample";
To generate table 16 and table 17, use "bsample,cluster(uniq_pair)".

Use all_observations.dta to generate result for "All observations" section in the table;
Use raw_performance_pairing.dta to generate result for "Raw performance pairing" section in the table;
Use contest_performance_pairing.dta to generate result for "contest performance pairing" section.
*/

//Baseline treatment------------
quietly{
use all_observations.dta,clear
keep if round_number==2&treatment==1
gen ATE_effort=. //effort change
gen ATE_time=. //stop time
gen ATE_productivity=. //productivity 
gen ATE_p_win=.
gen ATE_conf1=.

matrix observe=J(5,1,0)
levelsof new_data, local(gr)
foreach j of local gr{
	psmatch2 treated if new_data==`j',llr outcome(effort_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support 
	replace ATE_effort = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(stop_time_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_time = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(productivity_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_productivity = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(p_win_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_p_win = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(confidence_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_conf1 = r(ate) if  new_data==`j'&_support==1
}
//generate obs matrix
forval i=1/5{
local a=1
	foreach v of varlist ATE*{
		sum `v' , meanonly
		mat observe[`a',1]=r(mean) // filling each row, one at a time
		loc ++a
		}
}

matrix obs=observe'
}
matrix list obs

//program for Average treatment effect		
qui capture program drop myboot
quietly{
program define myboot, rclass
	use all_observations.dta,clear	
	preserve 
		gen ATE_effort=.
		gen ATE_time=.
		gen ATE_productivity=.
		gen ATE_p_win=.
		gen ATE_conf1=.
		keep if round_number == 2 & treatment == 1
		//bsample,cluster(uniq_pair)
		bsample
		levelsof new_data, local(gr)	
foreach j of local gr{
		psmatch2 treated if new_data==`j',llr outcome(effort_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support 
		replace ATE_effort = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(stop_time_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_time = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(productivity_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_productivity = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(p_win_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_p_win = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(confidence_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_conf1 = r(ate) if  new_data==`j'&_support==1
}
		sum ATE_effort
		return scalar a1=r(mean)
		sum ATE_time
		return scalar a2=r(mean)
		sum ATE_productivity
		return scalar a3=r(mean)
		sum ATE_p_win
		return scalar a4=r(mean)
		sum ATE_conf1
		return scalar a5=r(mean)
	restore
end 
}
//bootstrap for the average treatment effect
preserve
simulate ATE_effort=r(a1) ATE_time=r(a2) ATE_productivity=r(a3) ATE_p_win=r(a4) ATE_conf1=r(a5),rep($rep) nodots seed(1234): myboot
bstat ATE_effort ATE_time ATE_productivity ATE_p_win ATE_conf1,stat(obs)
restore

//FutureInfo treatment--------------------------------
quietly{
use all_observations.dta,clear
keep if round_number==2&treatment==3
gen ATE_effort=. //effort change
gen ATE_time=. //stop time
gen ATE_productivity=. //productivity 
gen ATE_p_win=.
gen ATE_conf1=.

matrix observe=J(5,1,0)
levelsof new_data, local(gr)
foreach j of local gr{
	psmatch2 treated if new_data==`j',llr outcome(effort_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support 
	replace ATE_effort = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(stop_time_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_time = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(productivity_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_productivity = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(p_win_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_p_win = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(confidence_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_conf1 = r(ate) if  new_data==`j'&_support==1
}
//generate obs matrix
forval i=1/5{
local a=1
	foreach v of varlist ATE*{
		sum `v' , meanonly
		mat observe[`a',1]=r(mean) // filling each row, one at a time
		loc ++a
		}
}

matrix obs=observe'
}
matrix list obs

//program for Average treatment effect		
qui capture program drop myboot
quietly{
program define myboot, rclass
	use all_observations.dta,clear	
	preserve 
		gen ATE_effort=.
		gen ATE_time=.
		gen ATE_productivity=.
		gen ATE_p_win=.
		gen ATE_conf1=.
		keep if round_number == 2 & treatment == 3
		//bsample,cluster(uniq_pair)
		bsample
		levelsof new_data, local(gr)	
foreach j of local gr{
		psmatch2 treated if new_data==`j',llr outcome(effort_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support 
		replace ATE_effort = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(stop_time_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_time = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(productivity_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_productivity = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(p_win_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_p_win = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(confidence_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_conf1 = r(ate) if  new_data==`j'&_support==1
}
		sum ATE_effort
		return scalar a1=r(mean)
		sum ATE_time
		return scalar a2=r(mean)
		sum ATE_productivity
		return scalar a3=r(mean)
		sum ATE_p_win
		return scalar a4=r(mean)
		sum ATE_conf1
		return scalar a5=r(mean)
	restore
end 
}
//bootstrap for the average treatment effect
preserve
simulate ATE_effort=r(a1) ATE_time=r(a2) ATE_productivity=r(a3) ATE_p_win=r(a4) ATE_conf1=r(a5),rep($rep) nodots seed(1234): myboot
bstat ATE_effort ATE_time ATE_productivity ATE_p_win ATE_conf1,stat(obs)
restore

//PastInfo treamtment--------------------------------
quietly{
use all_observations.dta,clear
keep if round_number==2&treatment==2
gen ATE_effort=. //effort change
gen ATE_time=. //stop time
gen ATE_productivity=. //productivity 
gen ATE_p_win=.
gen ATE_conf1=.

matrix observe=J(5,1,0)
levelsof new_data, local(gr)
foreach j of local gr{
	psmatch2 treated if new_data==`j',llr outcome(effort_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support 
	replace ATE_effort = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(stop_time_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_time = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(productivity_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_productivity = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(p_win_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_p_win = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(confidence_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_conf1 = r(ate) if  new_data==`j'&_support==1
}
//generate obs matrix
forval i=1/5{
local a=1
	foreach v of varlist ATE*{
		sum `v' , meanonly
		mat observe[`a',1]=r(mean) // filling each row, one at a time
		loc ++a
		}
}

matrix obs=observe'
}
matrix list obs

//program for Average treatment effect		
qui capture program drop myboot
quietly{
program define myboot, rclass
	use all_observations.dta,clear	
	preserve 
		gen ATE_effort=.
		gen ATE_time=.
		gen ATE_productivity=.
		gen ATE_p_win=.
		gen ATE_conf1=.
		keep if round_number == 2 & treatment == 2
		bsample,cluster(uniq_pair)
		//bsample
		levelsof new_data, local(gr)	
foreach j of local gr{
		psmatch2 treated if new_data==`j',llr outcome(effort_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support 
		replace ATE_effort = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(stop_time_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_time = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(productivity_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_productivity = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(p_win_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_p_win = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(confidence_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_conf1 = r(ate) if  new_data==`j'&_support==1
}
		sum ATE_effort
		return scalar a1=r(mean)
		sum ATE_time
		return scalar a2=r(mean)
		sum ATE_productivity
		return scalar a3=r(mean)
		sum ATE_p_win
		return scalar a4=r(mean)
		sum ATE_conf1
		return scalar a5=r(mean)
	restore
end 
}
//bootstrap for the average treatment effect
preserve
simulate ATE_effort=r(a1) ATE_time=r(a2) ATE_productivity=r(a3) ATE_p_win=r(a4) ATE_conf1=r(a5),rep($rep) nodots seed(1234): myboot
bstat ATE_effort ATE_time ATE_productivity ATE_p_win ATE_conf1,stat(obs)
restore



//PastWinUn treatment--------------------------------
quietly{
use all_observations.dta,clear
keep if round_number==2&treatment==4
gen ATE_effort=. //effort change
gen ATE_time=. //stop time
gen ATE_productivity=. //productivity 
gen ATE_p_win=.
gen ATE_conf1=.

matrix observe=J(5,1,0)
levelsof new_data, local(gr)
foreach j of local gr{
	psmatch2 treated if new_data==`j',llr outcome(effort_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support 
	replace ATE_effort = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(stop_time_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_time = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(productivity_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_productivity = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(p_win_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_p_win = r(ate) if  new_data==`j'&_support==1
	psmatch2 treated if new_data==`j',llr outcome(confidence_change) pscore(p_score) ate common bwidth($bw) 
	label drop _support
	replace ATE_conf1 = r(ate) if  new_data==`j'&_support==1
}
//generate obs matrix
forval i=1/5{
local a=1
	foreach v of varlist ATE*{
		sum `v' , meanonly
		mat observe[`a',1]=r(mean) // filling each row, one at a time
		loc ++a
		}
}

matrix obs=observe'
}
matrix list obs

//program for Average treatment effect		
qui capture program drop myboot
quietly{
program define myboot, rclass
	use all_observations.dta,clear	
	preserve 
		gen ATE_effort=.
		gen ATE_time=.
		gen ATE_productivity=.
		gen ATE_p_win=.
		gen ATE_conf1=.
		keep if round_number == 2 & treatment == 4
		bsample,cluster(uniq_pair)
		//bsample
		levelsof new_data, local(gr)	
foreach j of local gr{
		psmatch2 treated if new_data==`j',llr outcome(effort_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support 
		replace ATE_effort = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(stop_time_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_time = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(productivity_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_productivity = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(p_win_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_p_win = r(ate) if  new_data==`j'&_support==1
		psmatch2 treated if new_data==`j',llr outcome(confidence_change) pscore(p_score) ate common bwidth($bw) 
		label drop _support
		replace ATE_conf1 = r(ate) if  new_data==`j'&_support==1
}
		sum ATE_effort
		return scalar a1=r(mean)
		sum ATE_time
		return scalar a2=r(mean)
		sum ATE_productivity
		return scalar a3=r(mean)
		sum ATE_p_win
		return scalar a4=r(mean)
		sum ATE_conf1
		return scalar a5=r(mean)
	restore
end 
}
//bootstrap for the average treatment effect
preserve
simulate ATE_effort=r(a1) ATE_time=r(a2) ATE_productivity=r(a3) ATE_p_win=r(a4) ATE_conf1=r(a5),rep($rep) nodots seed(1234): myboot
bstat ATE_effort ATE_time ATE_productivity ATE_p_win ATE_conf1,stat(obs)
restore


//=============================testing difference between treatment in confidence1 (in main text)-------
//T1 vs T2
ttesti 90 20.52 30.357 100 16.24 36.6
//T1 vs T4					
ttesti 90 20.52 30.357 102 10.08 28.077	
//T2 vs T4
ttesti  100 16.24 36.6 102 10.08 28.077	

//strata method 
//T1 vs T4			
ttesti 116 20.52 26.29 112 10.08 36.300




